#[non_exhaustive]pub enum ConfigError {
MustBePositive {
field: &'static str,
},
UnsafeSetting {
field: &'static str,
because: &'static str,
},
Contradiction {
first: &'static str,
second: &'static str,
},
OutOfRange {
field: &'static str,
},
}Expand description
A configuration value the library refuses to work with.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
MustBePositive
A bound that must allow at least one of something was zero.
UnsafeSetting
A safety setting was turned off, and the library has no such mode.
Fields
Contradiction
Two settings ask for incompatible things.
Fields
OutOfRange
A ratio expressed in per mille left the 0..=1000 range.