missing

Function missing 

pub fn missing(copy: &dyn ServerCopy, locale: &Locale) -> Vec<&'static str>
The sentences of copy with no text in the language of locale. The default text is English, so English is always served.