#[non_exhaustive]pub struct EffortConfig {
pub default: Effort,
pub low: EffortOverrides,
pub medium: EffortOverrides,
pub high: EffortOverrides,
}Expand description
The default level, and what a deployment changes about each.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.default: EffortThe level of a turn that does not force one.
low: EffortOverridesChanges to low.
medium: EffortOverridesChanges to medium.
high: EffortOverridesChanges to high.
Implementations
Sourceimpl EffortConfig
impl EffortConfig
Sourcepub const fn conservative() -> Self
pub const fn conservative() -> Self
medium by default, and every level as shipped.
Sourcepub const fn overrides(&self, effort: Effort) -> &EffortOverrides
pub const fn overrides(&self, effort: Effort) -> &EffortOverrides
What a deployment changes about effort.