pub fn error_code(error: &OrchestratorError) -> StringExpand description
A stable code for an orchestrator failure, safe to put on the wire.
pub fn error_code(error: &OrchestratorError) -> StringA stable code for an orchestrator failure, safe to put on the wire.