Module reason

Module reason 

Reason keys the engine adds to the ones in turnframe_core::policy::reason.

Constants

BLOCKED_BY_CONSTRAINT
A constraint the user placed on the turn blocks the command.
BLOCKED_BY_MODE
The orchestration mode is not eligible for this risk class (11.4).