The effort a turn runs at, resolved into the profiles, budgets and settings it runs
under. medium with nothing configured is the configuration as it is.
Structs
- Effort
Config - The default level, and what a deployment changes about each.
- Effort
Overrides - What a deployment changes about one level.
- Effort
Profile - One level, resolved: what a turn at that level runs under.
Enums
- Effort
- How hard a turn works to be read correctly.
Functions
- resolve
- What a turn at
effortruns under.