Reason keys the engine adds to the ones in
turnframe_core::policy::reason.
Constants
- BLOCKED_
BY_ CONSTRAINT - A constraint the user placed on the turn blocks the command.
- BLOCKED_
BY_ MODE - The orchestration mode is not eligible for this risk class (11.4).