pub trait CaseIdFactory: Send + Sync {
// Required method
fn new_case_id(
&self,
workflow: &WorkflowKey,
turn_id: &TurnId,
act: ActId,
) -> CaseId;
}Expand description
Mints the identifier of a case that does not exist yet.
Injected so applications keep their identifier format. It must be a pure function of its arguments: the identifier is in the plan hash (I20).
Required Methods
Sourcefn new_case_id(
&self,
workflow: &WorkflowKey,
turn_id: &TurnId,
act: ActId,
) -> CaseId
fn new_case_id( &self, workflow: &WorkflowKey, turn_id: &TurnId, act: ActId, ) -> CaseId
The identifier for the new case act of turn_id asks for.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".