#[non_exhaustive]pub enum TraceEvent<'a> {
Received {
input: &'a TurnInput,
},
Step {
turn: TurnId,
step: &'a Step,
},
Understood {
turn: TurnId,
understanding: &'a Understanding,
},
Reduced {
turn: TurnId,
plan: &'a ReductionPlan,
},
Completed {
reply: &'a AssistantTurn,
record: &'a ReplayRecord,
},
Failed {
turn: TurnId,
code: &'a str,
record: &'a ReplayRecord,
},
}Expand description
One thing a turn did, as a trace receives it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Received
A turn arrived.
Step
Understanding decided something.
Understood
What the message was understood to say, card acts included.
Reduced
What the reducer decided.
Completed
The turn finished and this is the reply the user got.
Failed
The turn failed.